# coding=iso-8859-15
#
# Newsflash action script.
#
# (c) Sami Visnen 2007
#
# Please modify this file to suit your needs. 
#
# This script plays little sound notifications when
# some interesting events happen in the application.
#
import os
import sys
import flash.host
import time

def where_am_i():
    """ Return a string telling the file system location for the host executable.
    Newsflash sets argv[1] to the binary folder from which the
    executable is started. """
    if len(sys.argv) < 2:
        return ''
    arg=sys.argv[1]
    if len(arg) == 0:
        return ''
    if os.name == 'posix':
        if arg[len(arg)-1] != '/':
            arg = arg + '/'
    if os.name == 'nt':
        if arg[len(arg)-1] != '\\':
            arg = arg + '\\'
    return arg

if os.name == 'posix':
    import ossaudiodev
    import wave
elif os.name == 'nt':
    import winsound

errorWav=True
downloadWav=True
updateWav=True
last_play=0.0

flash.host.add_log('$Id: action_playsound.py,v 1.11 2008/06/25 14:16:34 enska Exp $')

base=where_am_i()
if os.path.exists(base + 'media/download.wav')==False:
    flash.host.add_log(base + 'media/download.wav' + ' not found. Notification disabled.')
    downloadWav=False
if os.path.exists(base + 'media/error.wav') == False:
    errorWav=False
    flash.host.add_log(base + 'media/error.wav' + ' not found. Notification disabled.')
if os.path.exists(base + 'media/update.wav') == False:
    updateWav=False
    flash.host.add_log(base + 'media/update.wav' + ' not found. Notification disabled.')

def playsound(file):
    if os.name == 'posix':
        wav=None
        dsp=None
        try:
            wav=wave.open(file, 'r')
            (nc,sw,fr,nf,comptype, compname) = wav.getparams( )

            # im really sorry for using oss here. It might not work for you
            # if you dont have a HW audio mixer.
            # todo: try to use linuxaudiodev instead (goes through ALSA?)
            dsp=ossaudiodev.open('/dev/dsp', 'w')
            AFMT_S16_NE = ossaudiodev.AFMT_S16_LE
            dsp.setparameters(AFMT_S16_NE, nc, fr)
            dat=wav.readframes(nf)
            dsp.write(dat)
        finally:
            if wav != None:
                wav.close()
            if dsp !=None:
                dsp.close()
                
    elif os.name == 'nt':
        winsound.PlaySound(file, winsound.SND_FILENAME)

def should_play_now():
    global last_play
    if time.time()-last_play > 3.0:
        last_play=time.time()
        return True
    return False


def newsflash_batch_complete(location):
    """ This is the batch complete hook function.
    This is called whenever a batch download completes. The argument
    given specifies the location of the batch files (i.e. the folder)
    on the filesystem. """
    if downloadWav==True:
        file=where_am_i() + 'media/download.wav'
        playsound(file)

def newsflash_update_complete(location, group):
    """ This is the update_complete action hook function.
    This is called whenever a group update completes.
    Location specifies the location of the datafiles on the
    filesystem (.cat, .idx, .nbr and .nfo files).
    Group is the name of the group, e.g. alt.binaries.mp3.
    """
    if updateWav==True:
        file=where_am_i() + 'media/update.wav'
        playsound(file)


def newsflash_sys_error(msg, resource,code):
    """ This is the system error hook function.
    This is called whenever there has been an error with a system error code.
    Msg is the simple error message string.
    Resource is the resource in question to which the error applies. (A file, network server etc.)
    Code is the platform dependant error code. For linux this is errno and for
    Windows it can be either errno, WSAGetLastError or just GetLastError. (mostly errno) """
    if errorWav==True and should_play_now()==True:
        file=where_am_i() + 'media/error.wav'
        playsound(file)
    
def newsflash_app_error(msg, resource, code=None):
    """ This is the application error hook function.
    This is called whenever there has been an application defined error.
    Msg is the simple error message string.
    Resource is the resource in question to which this error applies.
    Code is the application defined error code. (todo: enum these)"""
    if errorWav==True and should_play_now()==True:
        file=where_am_i() + 'media/error.wav'
        playsound(file)


